function ConstructBrownianPath(x,y,filename)
% We will construct the test normal random variables by splicing together
% vectors of different lengths with different standard deviations.

% Vector one: note this will contain the start and end points of the
% sequence.

% Note: the time step itself is already incorporated into the solver code.
% We need only introduce a random variable whose variance is a quarter that
% of the coarser level at each step. Thus at each stage the standard
% deviation decreases by a half. Furthemore, with the exception of the
% coarsest level, the number of points at each level will increase by the
% number points in the previous level, as for each one point we will now
% add two points.

% At a basic time step of 1ms for 500 ms activity we will need 501
% points. We can put in a few more to ensure the fit!

% Therefore given that the endpoints will be included in the first layer we
% will need 499 as our factor in all other layers.

% Three columns are required, one for each  variable.

factor = 24999;

filename =strcat(filename, '_', num2str(x, '%1.2f'), '_', num2str(y, '%1.2f'), '.data');
for i=0:4
    if i==0
        random_number_vector_level = randn(factor+2, 2);
        main_vector = random_number_vector_level;
        time_vector = 0:(0.1*(2^(-i))):400;
    else
        [m1,n1] = size(main_vector);
        random_number_vector_level = (2^(-i))*randn(m1, 2);
        % splice the data into the base vector. note this is the number
        % that must be added (minus a factor timestep) and so where before
        % we had DWh we must now have 1/2 DWh +Z, 1/2DWh-Z!
        holding_vector = zeros(2*m1,2);
        holding_vector(1:2:end,:) = 0.5*main_vector+random_number_vector_level;
        holding_vector(2:2:end,:) = 0.5*main_vector-random_number_vector_level;
        main_vector = holding_vector;
        time_vector = 0:(0.1*(2^(-i))):400;
    end
end

% cd Dataset

% Write data to file
fid = fopen(filename, 'w');
fprintf(fid, '%12.8f %12.8f\n', main_vector);
fclose(fid);

clear all

end
