function Figure10A
%% Generates the example conserved Brownian path in figure 10A.

% I used export_fig to export my figures. Setting export_fig = 0 will disable
% saving of the figures with export_fig. You can download export_fig from the 
% MathWorks file exchange.

%% Setup
user= 'USER';
project_path = ['/home/' user '/chaste-source/StochasticPhenomenologicalModels'];
output_path = [ '/tmp/' user '/testoutput' ];
matlab_path = [ project_path '/Matlab' ];
% export_fig?
exportFig = 0;

%% load data
data = load([ project_path '/test/data/BrownianPath/BrownianPath_0.00_0.00.data' ] );

% look at a subset of the data so that all steps are visible in plot
sample_data = data(1:64);
% The raw data is the Weiner increments at the finest refinement level
% time step is 0.000625 ms in this case
time_1 = 0.000625*(0:64);
% Brownian path is the cumulative sum of these Weiner increments.
data_1 = cumsum([0 sample_data]);

% Path is generated in such a way that adding adjacent points gives the Weiner 
% increment at the next refinement level:
%  ( 0.5 * Wh - Z) + (0.5 * Wh +Z) = Wh
sample_data_2 = sample_data(1:2:63) + sample_data(2:2:64);
% Path is sum of increments
data_2 = cumsum([0 sample_data_2]);
% time step is twice the size (0.00125)
time_2 = 0.00125*(0:32);
% ... etc
sample_data_3 = sample_data_2(1:2:31) + sample_data_2(2:2:32);
data_3 = cumsum([0 sample_data_3]);
time_3 = 0.0025*(0:16);

sample_data_4 = sample_data_3(1:2:15) + sample_data_3(2:2:16);
data_4 = cumsum([0 sample_data_4]);
time_4 = 0.005*(0:8);

sample_data_5 = sample_data_4(1:2:7) + sample_data_4(2:2:8);
data_5 = cumsum([0 sample_data_5]);
time_5 = 0.01*(0:4);
cd(matlab_path)
%% plot figure
figure;
% plot data
hold on
plot(time_1, data_1,'-ko', 'LineWidth', 2.0, 'MarkerSize', 5.0, 'MarkerFaceColor', 'k')
plot(time_2, data_2, '-bo', 'LineWidth', 2.0, 'MarkerSize', 5.0, 'MarkerFaceColor', 'b')
plot(time_3, data_3, '-ro', 'LineWidth', 2.0, 'MarkerSize', 5.0, 'MarkerFaceColor', 'r')
plot(time_4, data_4, '-go', 'LineWidth', 2.0, 'MarkerSize', 5.0, 'MarkerFaceColor', 'g')
plot(time_5, data_5, '-co', 'LineWidth', 2.0, 'MarkerSize', 5.0, 'MarkerFaceColor', 'c')
% label axes
xlabel('Time (ms)');
ylabel('b(t)');
% cosmetics
set(gca, 'FontSize', 26);
set(gca, 'LineWidth', 2.0);
set(findall(gca, 'Type', 'text'), 'FontSize', 30);
% save if requested
if exportFig
	export_fig( 'Fig10A_ConservedBrownianPath.eps', '-eps', '-transparent' )
end
end
