function Figure1A
% Plot the single cell traces and simulations in Fig 1A

% I used export_fig to export my figures. Setting export_fig = 0 will disable
% saving of the figures with export_fig. You can download export_fig from the 
% MathWorks file exchange.

%% Setup
user= 'USER';
project_path = ['/home/' user '/chaste-source/StochasticPhenomenologicalModels'];
output_path = [ '/tmp/' user '/testoutput' ];
matlab_path = [ project_path '/Matlab' ];
% export_fig?
exportFig = 0;

%% Experimental traces

% Matlab script to find APD90s for single cell experimental data 
data1 = 'Data/Actionpotentials080624cell4.csv';
data2 = 'Data/Actionpotentials080624cell2.csv';
data3 = 'Data/Actionpotentials080620cell1.csv';
data4 = 'Data/Actionpotentials080620cell3.csv';

% Data file is labelled AP. First column is time.
AP1 = load(data1);
AP2 = load(data2);
AP3 = load(data3);
AP4 = load(data4);

% Rescale transmembrane potentials
AP1(:,2:end) = 0.1*AP1(:,2:end);
AP2(:,2:end) = 0.1*AP2(:,2:end);
AP3(:,2:end) = 0.1*AP3(:,2:end);
AP4(:,2:end) = 0.1*AP4(:,2:end);

% Rescale times
AP1(:,1) = 1000*AP1(:,1);
AP2(:,1) = 1000*AP2(:,1);
AP3(:,1) = 1000*AP3(:,1);
AP4(:,1) = 1000*AP4(:,1);

% Determine size of AP
[m1, n1] = size(AP1);
[m2, n2] = size(AP2);
[m3, n3] = size(AP3);
[m4, n4] = size(AP4);

% plot action potentials
figureHandle = figure;
subplot(2,4,1),
hold on
% limits give data originally used for model construction (Walmsley et al 2010)
% For cell 1 use first 94 only
for i = 2:95
    plot(AP1(:,1), AP1(:,i),'r-')
end
%xlabel('Time (ms)')
ylabel('Membrane Potential (mV)')
axis([0 400 -100 100])
hold off

subplot(2,4,2),
hold on
% For apex cell 2 use 50-100
for i = 51:101
    plot(AP2(:,1), AP2(:,i),'r-')
end
%xlabel('Time (ms)')
%ylabel('Membrane Potential (mV)')
axis([0 400 -100 100])
hold off

subplot(2,4,3),
hold on
% for base cell 1 use 1-48
for i = 2:49
    plot(AP3(:,1), AP3(:,i),'r-')
end
%xlabel('Time (ms)')
%ylabel('Membrane Potential (mV)')
axis([0 400 -100 100])
hold off

subplot(2,4,4),
hold on
% for base cell 2 use 50-125
for i = 51:126
    plot(AP4(:,1), AP4(:,i),'r-')
end
%xlabel('Time (ms)')
%ylabel('Membrane Potential (mV)')
axis([0 400 -100 100])
hold off

GP_apex_1_rest = -73.8580;
GP_apex_1_V = 94.0553;
GP_apex_2_rest = -77.7740;
GP_apex_2_V = 103.7665;
GP_base_1_rest = -78.1110;
GP_base_1_V = 94.6066;
GP_base_2_rest = -76.0520;
GP_base_2_V = 90.4975;

%% plot simulated action potentials

cd(output_path)
cd('SingleCellSims/Stochastics')

% Apex cell 1
subplot(2,4,5),
hold on
ModelAPDsApexCell1 = zeros(1,99);
% loop over traces
for i = 1:99
    fileName = sprintf('GP_Apex_1_stoch_trace_%i.dat',i);
    data = load(fileName);
    plot(data(:,1)+7, GP_apex_1_V*data(:,2)+GP_apex_1_rest,'k-')
	% calculate APD
    ModelAPDsApexCell1(i) = find_APD(data(:,1)+7,GP_apex_1_V*data(:,2)+GP_apex_1_rest,90);    
end
xlabel('Time (ms)')
ylabel('Membrane Potential (mV)')
axis([0 400 -100 100])
hold off


% apex cell 2

subplot(2,4,6),
hold on
ModelAPDsApexCell2 = zeros(1,99);
for i = 1:99
    fileName = sprintf('GP_Apex_2_stoch_trace_%i.dat',i);
    data = load(fileName);
    plot(data(:,1)+7, GP_apex_2_V*data(:,2)+GP_apex_2_rest,'k-')
    ModelAPDsApexCell2(i) = find_APD(data(:,1)+7,GP_apex_2_V*data(:,2)+GP_apex_2_rest,90);   
end
xlabel('Time (ms)')
axis([0 400 -100 100])
hold off

subplot(2,4,7),
hold on

ModelAPDsBaseCell1 = zeros(1,99);

for i = 1:99
    fileName = sprintf('GP_Base_1_stoch_trace_%i.dat',i);
    data = load(fileName);
    plot(data(:,1)+9, GP_base_1_V*data(:,2)+GP_base_1_rest,'k-')
    ModelAPDsBaseCell1(i) = find_APD(data(:,1)+9, GP_base_1_V*data(:,2)+GP_base_1_rest,90);
end
xlabel('Time (ms)')
axis([0 400 -100 100])
hold off

subplot(2,4,8),
hold on

ModelAPDsBaseCell2 = zeros(1,99);

for i = 1:99
    fileName = sprintf('GP_Base_2_stoch_trace_%i.dat',i);
    data = load(fileName);
    plot(data(:,1)+6, GP_base_2_V*data(:,2)+GP_base_2_rest,'k-')
    ModelAPDsBaseCell2(i) = find_APD(data(:,1)+9, GP_base_2_V*data(:,2)+GP_base_2_rest,90);
end
xlabel('Time (ms)')
axis([0 400 -100 100])
hold off
    
allAxesInFigure = findall(figureHandle,'type','axes');
    
for ax=1:length(allAxesInFigure)
    set(allAxesInFigure(ax), 'FontSize', 16)
    set(findall(allAxesInFigure(ax), 'Type','text'), 'FontSize', 18)
    set(allAxesInFigure(ax), 'LineWidth', 1.5)

end

cd(matlab_path)
if exportFig
	export_fig( 'Fig1A_ExpSimTraces.eps','-eps','-transparent')
end

%% Write summary of APDs to file

APDsSummaryFile = fopen('StochasticModelAPDSummary.dat', 'w');
fprintf(APDsSummaryFile, 'Apex Cell 1\n');
fprintf(APDsSummaryFile, 'Mean APD: %3.2f\n', mean(ModelAPDsApexCell1)); 
fprintf(APDsSummaryFile, 'Var APD: %3.2f\n', var(ModelAPDsApexCell1)); 
fprintf(APDsSummaryFile, 'Median APD: %3.2f\n', median(ModelAPDsApexCell1)); 
fprintf(APDsSummaryFile, 'Min APD: %3.2f\n', min(ModelAPDsApexCell1));
fprintf(APDsSummaryFile, 'Max APD: %3.2f\n', max(ModelAPDsApexCell1));
fprintf(APDsSummaryFile, 'Range APD: %3.2f\n', max(ModelAPDsApexCell1) - min(ModelAPDsApexCell1));

fprintf(APDsSummaryFile, 'Apex Cell 2\n');
fprintf(APDsSummaryFile, 'Mean APD: %3.2f\n', mean(ModelAPDsApexCell2)); 
fprintf(APDsSummaryFile, 'Var APD: %3.2f\n', var(ModelAPDsApexCell2)); 
fprintf(APDsSummaryFile, 'Median APD: %3.2f\n', median(ModelAPDsApexCell2)); 
fprintf(APDsSummaryFile, 'Min APD: %3.2f\n', min(ModelAPDsApexCell2));
fprintf(APDsSummaryFile, 'Max APD: %3.2f\n', max(ModelAPDsApexCell2));
fprintf(APDsSummaryFile, 'Range APD: %3.2f\n', max(ModelAPDsApexCell2) - min(ModelAPDsApexCell2));

fprintf(APDsSummaryFile, 'Base Cell 1\n');
fprintf(APDsSummaryFile, 'Mean APD: %3.2f\n', mean(ModelAPDsBaseCell1)); 
fprintf(APDsSummaryFile, 'Var APD: %3.2f\n', var(ModelAPDsBaseCell1)); 
fprintf(APDsSummaryFile, 'Median APD: %3.2f\n', median(ModelAPDsBaseCell1)); 
fprintf(APDsSummaryFile, 'Min APD: %3.2f\n', min(ModelAPDsBaseCell1));
fprintf(APDsSummaryFile, 'Max APD: %3.2f\n', max(ModelAPDsBaseCell1));
fprintf(APDsSummaryFile, 'Range APD: %3.2f\n', max(ModelAPDsBaseCell1) - min(ModelAPDsBaseCell1));

fprintf(APDsSummaryFile, 'Base Cell 2\n');
fprintf(APDsSummaryFile, 'Mean APD: %3.2f\n', mean(ModelAPDsBaseCell2)); 
fprintf(APDsSummaryFile, 'Var APD: %3.2f\n', var(ModelAPDsBaseCell2)); 
fprintf(APDsSummaryFile, 'Median APD: %3.2f\n', median(ModelAPDsBaseCell2)); 
fprintf(APDsSummaryFile, 'Min APD: %3.2f\n', min(ModelAPDsBaseCell2));
fprintf(APDsSummaryFile, 'Max APD: %3.2f\n', max(ModelAPDsBaseCell2));
fprintf(APDsSummaryFile, 'Range APD: %3.2f\n', max(ModelAPDsBaseCell2) - min(ModelAPDsBaseCell2));

fclose(APDsSummaryFile);

end

function [APD, max_V, repolarisation_threshold] = find_APD(T,Y, percentage)
% We define the APD as the time from maximum upstroke to the time of 90%
% depolarisation. Note: max upstroke is defined as point of highest
% gradient
assert(0 < percentage && percentage < 100, 'Percentage must lie between 0 and 100')
factor = (100-percentage)/100;
APD=0;
% to find the gradient
grad = diff(Y)./diff(T);
[maximum_upstroke, grad_index] = max(grad);
time_of_max_upstroke = T(grad_index+1); %+1 necessary due to nature of diff.
rest_potential = Y(1);
[max_V, max_V_index] = max(Y);
repolarisation_threshold = factor*(max_V -rest_potential) +rest_potential;
repolarisation_index_part = find(Y(max_V_index:end) < repolarisation_threshold, 1); % Finds the index in a vector of length Y(end) - max_V_index + 1
if isempty(repolarisation_index_part) % ie model doesn't reach repolarisation.
    APD = T(end)-time_of_max_upstroke;
else
    repolarisation_index = max_V_index + repolarisation_index_part-1;
    repolarisation_time = (repolarisation_threshold*(T(repolarisation_index)-T(repolarisation_index-1)) ...
        +Y(repolarisation_index)*T(repolarisation_index-1) -Y(repolarisation_index-1)*T(repolarisation_index))*(1/(Y(repolarisation_index)-Y(repolarisation_index-1)));
    APD = repolarisation_time - time_of_max_upstroke;
end

end
