function Figure3
%% Generates the tissue APD distribution plots for figure 3. The 
% variables project_path and output_path should be changed to be made 
% appropriate to the user.

% I used export_fig to export my figures. Setting export_fig = 0 will disable
% saving of the figures with export_fig. You can download export_fig from the 
% MathWorks file exchange.

%% Setup
user= 'USER';
project_path = ['/home/' user '/chaste-source/StochasticPhenomenologicalModels'];
output_path = [ '/tmp/' user '/testoutput' ];
matlab_path = [ project_path '/Matlab' ];
% export_fig?
exportFig = 0;
% beats to investigate
beats = 49;
% conductivities to simulate
conductivities=[1 0.5 0.1 0.05];
% number of cell models to investigate
cell_models = 1;

%% load data
% change to data directory
cd( [ output_path '/StochasticsRegularPacing_archives' ] );

% loop over cell models
for cell_model = cell_models
    % initialise array to hold APD data
    detResultsArray = zeros(98,49, length(conductivities), length(beats));
    stochResultsArray = zeros(98,49, length(conductivities), length(beats));
    % loop over conductivities    
    for cond =1:length(conductivities)
        % loop over beats
        for i=1:length(beats)
            % change into deterministic archive.
            cd(['archive_CS_' num2str(conductivities(cond)) '_cell_model_' num2str(cell_model) '_stim_' num2str(beats(i)) '/']);
            
            % Get the data out of the relevant archive folder and reshape to square
            data = importdata('Apd_90_0pt40_Map.dat');
            deterministicdata = reshape(data,100,100);
            deterministicdata = deterministicdata';
			% remove boundary effects (Cherry and Fenton 2011)        
            deterministicdata = deterministicdata(:,25:75);
            
	    	cd ../
			% repeat for stochastic APD map
            cd(['archive_CS_' num2str(conductivities(cond)) '_cell_model_' num2str(cell_model) '_stim_' num2str(beats(i)) '_stochastic/']);
            
            % Get the data out of the relevant archive folder and reshape to square
            data = importdata('Apd_90_0pt40_Map.dat');
            stochasticdata = reshape(data,100,100);
            stochasticdata = stochasticdata';
            stochasticdata = stochasticdata(:,25:75);
            
            cd ../
			% load data into results array
            detResultsArray(:,:,cond,i) = deterministicdata(2:end-1, 2:end-1);
            stochResultsArray(:,:,cond,i) = stochasticdata(2:end-1, 2:end-1);
            
        end % loop over beats
        
    end % loop over conductivities
    
	%% plot results
	% change to Matlab directory
    cd( matlab_path );
    % get min and max of data over all conductivities
    minDetResults = min(min(min(min(detResultsArray))));
    minStochResults = min(min(min(min(stochResultsArray))));
    maxDetResults = max(max(max(max(detResultsArray))));
    maxStochResults = max(max(max(max(stochResultsArray))));
    dataMin = min(minDetResults, minStochResults);
    dataMax = max(maxDetResults, maxStochResults);

    % loop over conductivities
    for cond =1:length(conductivities)
        % loop over number of beats
        for i=1:length(beats)
            % open figure for deterministic results
            fig=figure('units','normalized','outerposition',[0.1 0.1 0.9 0.9]);
			% plot with imagesc
            imagesc(squeeze(detResultsArray(:,:,cond,i)))
			% remove ticks
            set(gca, 'XTickLabel', '');
            set(gca, 'YTickLabel', '');
            set(gca, 'XTick', []);
            set(gca, 'YTick', []);
            caxis([dataMin dataMax]);
			% set colour map
            colormap hot;
			% save figure
			if exportFig
            	export_fig(['Fig3_Cell_Model_' num2str(cell_model) '_CS_' num2str(conductivities(cond)) '_beat_' num2str(beats(i)) '_det.eps'], '-eps', '-transparent')
            end
			% repeat for the stochastic data
            fig=figure('units','normalized','outerposition',[0.1 0.1 0.9 0.9]);
            imagesc(squeeze(stochResultsArray(:,:,cond,i)))
            set(gca, 'XTickLabel', '');
            set(gca, 'YTickLabel', '');
            set(gca, 'XTick', []);
            set(gca, 'YTick', []);
            caxis([dataMin dataMax]);
            colormap hot;
			if exportFig
            	export_fig(['Fig3_Cell_Model_' num2str(cell_model) '_CS_' num2str(conductivities(cond)) '_beat_' num2str(beats(i)) '_stoch.eps'], '-eps', '-transparent')
			end
            
        end % loop over beats        
    end % loop over conductivities

    % make a figure with a colour bar on it for the plot (I don't put one on the above as it messes up the size).
    fig=figure('units','normalized','outerposition',[0.1 0.1 0.9 0.9]);
    imagesc(squeeze(detResultsArray(:,:,cond,i))); % doesn't matter what the content is
    set(gca, 'XTickLabel', '');
    set(gca, 'YTickLabel', '');
	% set the scale so that colour bar is correct
    caxis([dataMin dataMax]);
    colormap hot;
	% put on colour bar
    h=colorbar;
	% label colour bar
    set(h,'FontSize', 20)
    y=ylabel(h, 'APD_{90} (ms)');
    set(y, 'FontSize', 30);
    if exportFig
    	export_fig(['Fig3_Cell_Model_' num2str(cell_model) '_colourbar.eps'], '-eps', '-transparent')
    end
end % loop over cell models

end % function

