function Figure4
%% Generates the statistical summary plots beat by beat for figure 4. Also 
% provides a statistical summary in a text file (Fig2Summary.dat). project_path 
% and output_path should be changed to be made appropriate to the user.

% I used export_fig to export my figures. Setting export_fig = 0 will disable
% saving of the figures with export_fig. You can download export_fig from the 
% MathWorks file exchange.

%% Setup
user= 'USER';
project_path = ['/home/' user '/chaste-source/StochasticPhenomenologicalModels'];
output_path = [ '/tmp/' user '/testoutput' ];
matlab_path = [ project_path '/Matlab' ];
% export_fig?
exportFig = 0;
% beats to investigate
beats = 1:159;
% conductivities to simulate
conductivities=[1 0.5 0.1 0.05];

% initialise holding arrays
deterministic_mean = zeros(length(beats),length(conductivities));
deterministic_variance = zeros(length(beats),length(conductivities));
stochastic_mean = zeros(length(beats),length(conductivities));
stochastic_variance = zeros(length(beats),length(conductivities));
difference_variance = zeros(length(beats),length(conductivities));
diff_max = zeros(length(beats),length(conductivities));
diff_min = zeros(length(beats),length(conductivities));
abs_diff = zeros(length(beats),length(conductivities));


%% load data
% change into output directory
cd(output_path)
cd( 'StochasticsRapidPacing_archives' )
% loop over conductivity
for cond =1:length(conductivities)
    % loop over beats
    for i=1:length(beats)
		% get deterministic data
		cd(['archive_' num2str(beats(i)) '_CS_' num2str(conductivities(cond))]);
        alldata = importdata('Apd_90_0pt40_Map.dat');
        deterministicdata = reshape(alldata,100,100);
        deterministicdata = deterministicdata';
		% remove boundary effects (Cherry and Fenton 2011)
        deterministicdata = deterministicdata(:,25:75);       
		cd ..
        
        % Get stochastic data
        cd(['archive_' num2str(beats(i)) '_CS_' num2str(conductivities(cond)) '_stochastic']);
        alldata = importdata('Apd_90_0pt40_Map.dat');
        stochasticdata = reshape(alldata,100,100);
        stochasticdata = stochasticdata';
        stochasticdata = stochasticdata(:,25:75);
        cd ..
		% calculate the difference between the determinsitic and stochastic data
        difference = deterministicdata-stochasticdata;
        
        % now calculate stats
        % mean APD per beat
        stochastic_mean(i,cond) = mean(mean(stochasticdata(2:end-1,2:end-1)));
        deterministic_mean(i,cond) = mean(mean(deterministicdata(2:end-1,2:end-1)));
        % variance in APD per beat
        stochastic_variance(i,cond) = var(reshape(stochasticdata(2:end-1,2:end-1), 98*49,1));
        deterministic_variance(i,cond) = var(reshape(deterministicdata(2:end-1,2:end-1), 98*49,1));
        % difference in variance
        difference_vector = reshape(difference, 100*51,1);
        difference_variance(i,cond) = var(difference_vector);
        % difference  between determinsitic and stochastic
        diff_min(i,cond) = min(min(difference));
        diff_max(i,cond) = max(max(difference));
        % absolute difference between deterministic and stochastic
        abs_diff(i,cond) = max(max(abs(difference)));
        
    end % loop over beats
    
end % loop overconductivities

cd(matlab_path)

% Plot the mean APD for the stochastic and determinisitic cases

colours = {'r', 'g', 'b', 'k'};
% get min and max of mean data for axis
min_data = min([min(min(deterministic_mean(6:end,:))), min(min(stochastic_mean(6:end,:)))]);
max_data = max([max(max(deterministic_mean(6:end,:))), max(max(stochastic_mean(6:end,:)))]);

% open figure
figureHandle = figure('units','normalized','outerposition',[0 0.4 1 0.65]);
% plot deterministic means
subplot(1,2,1);
hold on
% loop over conductivities
for i=1:length(conductivities)
    colour = colours{i};
    plot(squeeze(deterministic_mean(:,i)), colour, 'LineWidth', 2.0);
end
% set axes
ylim([0.95*min_data 1.05*max_data]);
xlim([0 160])
% set labels
xlabel('Beat Number')
ylabel('Mean APD{_{90}} (ms)')

% plot stochastic means
subplot(1,2,2);
hold on
% loop over conductivities
for i=1:length(conductivities)
    colour = colours{i};
    plot(squeeze(stochastic_mean(:,i)), colour, 'LineWidth', 2.0);
end
% set axes
ylim([0.95*min_data 1.05*max_data]);
xlim([0 160])
% set labels
xlabel('Beat Number')
ylabel('Mean APD{_{90}} (ms)')

% do cosmetics
allAxesInFigure = findall(figureHandle,'type','axes');

for ax=1:length(allAxesInFigure)
    set(allAxesInFigure(ax), 'FontSize', 20)
    set(findall(allAxesInFigure(ax), 'Type','text'), 'FontSize', 26)
    set(allAxesInFigure(ax), 'LineWidth', 2)
    set(allAxesInFigure(ax), 'Box', 'Off')
end
% save figure
if exportFig
	export_fig('Fig4_RapidPacingAPDMean.eps', '-eps', '-transparent');
end

% Plot the variance for the stochastic and determinisitic cases
colours = {'r', 'g', 'b', 'k'};

% get the max of the data for the axes
max_data = max([max(max(deterministic_variance(2:end,:))), max(max(stochastic_variance(2:end,:)))]);
% open figure
figureHandle = figure('units','normalized','outerposition',[0 0.4 1 0.65]);
subplot(1,2,1);
hold on
% plot deterministic variance
for i=1:length(conductivities)
    colour = colours{i};
    plot(squeeze(deterministic_variance(2:end,i)), colour, 'LineWidth', 2.0);
end
% set axes
ylim([0 1.05*max_data]);
xlim([0 160])
% set labels
xlabel('Beat Number')
ylabel('Variance in APD{_{90}} (ms{^2})')
% plot stochastic variance
subplot(1,2,2);
hold on
for i=1:length(conductivities)
    colour = colours{i};
    plot(squeeze(stochastic_variance(2:end,i)), colour, 'LineWidth', 2.0);
end
% set y limits
ylim([0 1.05*max_data]);
xlim([0 160])
% set axis labels
xlabel('Beat Number')
ylabel('Variance in APD{_{90}} (ms{^2})')
% cosmetics
allAxesInFigure = findall(figureHandle,'type','axes');

for ax=1:length(allAxesInFigure)
    set(allAxesInFigure(ax), 'FontSize', 20)
    set(findall(allAxesInFigure(ax), 'Type','text'), 'FontSize', 26)
    set(allAxesInFigure(ax), 'LineWidth', 2)
    set(allAxesInFigure(ax), 'Box', 'Off')
end

% save figure
if exportFig
	export_fig('Fig4_RapidPacingVariance.eps', '-eps', '-transparent');
end

% Plot the maximum absolute difference between the stochastic and determinisitic cases
colours = {'r', 'g', 'b', 'k'};
% get max data for axis 
max_data = max(max(abs_diff));
% open figure
figureHandle = figure('units','normalized','outerposition',[0 0.4 1 0.65]);
hold on
% plot difference in APD between stochastic and deterministic cases.
for i=1:length(conductivities)
    colour = colours{i};
    plot(squeeze(abs_diff(:,i)), colour, 'LineWidth', 2.0);
end
hold off
% set axes
ylim([0 1.05*max_data]);
xlim([0 160])
% axis labels
xlabel('Beat Number')
ylabel('Difference in APD{_{90}} (ms)')

% cosmetics
allAxesInFigure = findall(figureHandle,'type','axes');

for ax=1:length(allAxesInFigure)
    set(allAxesInFigure(ax), 'FontSize', 20)
    set(findall(allAxesInFigure(ax), 'Type','text'), 'FontSize', 26)
    set(allAxesInFigure(ax), 'LineWidth', 2)
    set(allAxesInFigure(ax), 'Box', 'Off')
end

% save figure
if exportFig
	export_fig('Fig4_RapidPacingAbsDifference.eps', '-eps', '-transparent');
end

end
