function Figure5
%% Generates the APD plots beat by beat for figure 5. Variables project_path 
% and output_path should be changed to be made appropriate to the user.

% I used export_fig to export my figures. Setting export_fig = 0 will disable
% saving of the figures with export_fig. You can download export_fig from the 
% MathWorks file exchange.

%% Setup
user= 'USER';
project_path = ['/home/' user '/chaste-source/StochasticPhenomenologicalModels'];
output_path = [ '/tmp/' user '/testoutput' ];
matlab_path = [ project_path '/Matlab' ];
% export_fig?
exportFig = 0;
% Beats to plot
beats = [74 75 76 77 78 79];
% Conductivities to plot
conductivities=[1 0.05];
overall_max = 0;
overall_min = 1000;
% Initialise arrays for data 
detArray = zeros(98, 51, length(beats), length(conductivities));
stochArray = zeros(98, 51, length(beats), length(conductivities));

%% Load data
cd(output_path)
cd( 'StochasticsRapidPacing_archives' )
for cond =1:length(conductivities)
    
    for i=1:length(beats)
        
        cd(['archive_' num2str(beats(i)) '_CS_' num2str(conductivities(cond))]);
        % Get the data out of the relevant archive folder and reshape to square
        alldata = importdata( 'Apd_90_0pt40_Map.dat');
        deterministicdata = reshape(alldata,100,100);
        deterministicdata = deterministicdata';
        deterministicdata = deterministicdata(2:end-1,25:75);
        
		% Track maximum and minimum values of deterministic data
        current_max_det = max(max(deterministicdata));
        if current_max_det > overall_max
            overall_max= current_max_det;
        end       
        current_min_det = min(min(deterministicdata));
        if current_min_det < overall_min
            overall_min = current_min_det;
        end
        cd ..
        % Get stochastic data.
        cd(['archive_' num2str(beats(i)) '_CS_' num2str(conductivities(cond)) '_stochastic']);
        % Get the data out of the relevant archive folder and reshape to square
        alldata = importdata('Apd_90_0pt40_Map.dat');
        stochasticdata = reshape(alldata,100,100);
        stochasticdata = stochasticdata';
        stochasticdata = stochasticdata(2:end-1,25:75);
        cd ..
		% Track maximum and minimum values of stochastic data
        current_max_stoch = max(max(stochasticdata));        
        if current_max_stoch > overall_max
            overall_max= current_max_stoch;
        end
        
        current_min_stoch = min(min(stochasticdata));
        if current_min_stoch < overall_min
            overall_min = current_min_stoch;
        end
        
		% Load data into arrays
        detArray(:,:,i,cond) = deterministicdata;
        stochArray(:,:,i,cond) = stochasticdata;
        
    end
end

%% Plot APD maps

% change to matlab folder
cd(matlab_path)
% loop over conductivity
for cond =1:length(conductivities)
    % loop over beats
    for i=1:length(beats)
        % open figure for deterministic plots
        figureHandle = figure;
		% plot APD maps
        imagesc(squeeze(detArray(:,:,i,cond)));
        set(gca,'xtick',[], 'ytick',[])
        set(gca,'xticklabel',[], 'yticklabel',[])
		% set colour map
        colormap hot;
        % Set colour range
        allAxesInFigure = findall(figureHandle,'type','axes');
        for ax=1:length(allAxesInFigure)
            set(allAxesInFigure(ax), 'clim', ([overall_min overall_max]));
        end
        % save figure
        if exportFig
	        export_fig(['Fig5_RapidPacingAPDMaps_CS_' num2str(conductivities(cond)) '_beat_' num2str(beats(i)) '.eps'], '-eps', '-transparent');
        end
		
		% open figure for stochastic plots        
        figureHandle = figure;
		% plot figure
        imagesc(squeeze(stochArray(:,:,i,cond)));
        set(gca,'xtick',[], 'ytick',[])
        set(gca,'xticklabel',[], 'yticklabel',[])
		% set colour map
        colormap hot;
        
		% set scale on figure
        allAxesInFigure = findall(figureHandle,'type','axes');
        
        for ax=1:length(allAxesInFigure)
            set(allAxesInFigure(ax), 'clim', ([overall_min overall_max]));
        end
        
		% save figure
		if exportFig
        	export_fig(['Fig5_RapidPacingAPDMaps_CS_' num2str(conductivities(cond)) '_beat_' num2str(beats(i)) '_stochastic.eps'], '-eps', '-transparent');
		end

    end % beats
    
end % conductivity

% generate colour bar figure
fig=figure('units','normalized','outerposition',[0 0 1 1]);
imagesc(stochasticdata); % contents don't matter
colormap hot;
% create color bar
h=colorbar;
set(gca, 'clim', ([overall_min overall_max]));
set(h,'FontSize', 20)
y=ylabel(h, 'APD_{90} (ms)');
set(y, 'FontSize', 26);

% save figure
if exportFig
	export_fig('Fig5_ColorBar.eps', '-eps', '-transparent');
end

end
