function Figure6
%% Generates the statistical summary plots beat by beat for figure 6. Variables
% project_path and output_path should be changed to be made appropriate to the 
% user.

% I used export_fig to export my figures. Setting export_fig = 0 will disable
% saving of the figures with export_fig. You can download export_fig from the 
% MathWorks file exchange.

%% Setup
user= 'USER';
project_path = ['/home/' user '/chaste-source/StochasticPhenomenologicalModels'];
output_path = [ '/tmp/' user '/testoutput' ];
matlab_path = [ project_path '/Matlab' ];
% export_fig?
exportFig = 0;
% beats to plot
beats = 0:49;
% conductivities
conductivities=[1 0.1 0.05];

% Initialise arrays for data
deterministic_mean = zeros(length(beats),length(conductivities));
deterministic_variance = zeros(length(beats),length(conductivities));
stochastic_mean = zeros(length(beats),length(conductivities));
stochastic_variance = zeros(length(beats),length(conductivities));
difference_variance = zeros(length(beats),length(conductivities));
diff_max = zeros(length(beats),length(conductivities));
diff_min = zeros(length(beats),length(conductivities));
abs_diff = zeros(length(beats),length(conductivities));

%% plot data
cd(output_path);
% loop over conductivities
for cond =1:length(conductivities)
    % loop over beats  
    for i=1:length(beats)
        cd([ 'RandomCellModel_CS_' num2str(conductivities(cond)) '_archives/archive_stim_' num2str(beats(i)) '/' ]);
        % Get the data out of the relevant archive folder and reshape to square
        alldata = importdata('Apd_90_0pt40_Map.dat');
        deterministicdata = reshape(alldata,101,101);
        deterministicdata = deterministicdata';
        deterministicdata = deterministicdata(:,25:75);       
        cd ../..
        % Get stochastic data.
        cd([ 'RandomCellModel_CS_' num2str(conductivities(cond)) '_stochastic_archives/archive_stim_' num2str(beats(i)) '/' ]);
        % Get the data out of the relevant archive folder and reshape to square
        alldata = importdata('Apd_90_0pt40_Map.dat');
        stochasticdata = reshape(alldata,101,101);
        stochasticdata = stochasticdata';
        stochasticdata = stochasticdata(:,25:75);
        cd ../..
		% calculate difference
        difference = deterministicdata(2:end-1,2:end-1)-stochasticdata(2:end-1,2:end-1);
        
        % now calculate stats
		% calculate the mean APD for the beat        
        stochastic_mean(i,cond) = mean(mean(stochasticdata(2:end-1,2:end-1)));
        deterministic_mean(i,cond) = mean(mean(deterministicdata(2:end-1,2:end-1)));
        % calculate the variance in the APD for the beat
        stochastic_variance(i,cond) = var(reshape(stochasticdata(2:end-1,2:end-1), 99*49,1));
        deterministic_variance(i,cond) = var(reshape(deterministicdata(2:end-1,2:end-1), 99*49,1));
        % calculate the difference between the deterministic and the stochastic simulations
        difference_vector = reshape(difference, 99*49,1);
        difference_variance(i,cond) = var(difference_vector);
        % calculate the mean and max differences
        diff_min(i,cond) = min(min(difference));
        diff_max(i,cond) = max(max(difference));
        abs_diff(i,cond) = max(max(abs(difference)));
    end % beats
end % conductivities

%% Plot figures
% change to matlab directory
cd(matlab_path);

% colours
det_colours = {'r--', 'g--', 'b--', 'k--'};
stoch_colours = {'r', 'g', 'b', 'k'};
% Get the min and max of the data for axes
min_data = min([min(min(deterministic_mean(2:end,:))), min(min(stochastic_mean(2:end,:)))]);
max_data = max([max(max(deterministic_mean(2:end,:))), max(max(stochastic_mean(2:end,:)))]);

% Plot the mean APD for the stochastic and determinisitic cases
figureHandle = figure('units','normalized','outerposition',[0 0.4 1 0.65]);
subplot(1,2,1);
hold on
% Plot the mean data for all beats
for i=1:length(conductivities)
    det_colour = det_colours{i};
    plot(squeeze(deterministic_mean(2:end,i)), det_colour, 'LineWidth', 2.0);
    stoch_colour = stoch_colours{i};
    plot(squeeze(stochastic_mean(2:end,i)), stoch_colour, 'LineWidth', 2.0);
end
% set axis
ylim([0.995*min_data 1.005*max_data]);
xlim([0 50])
% set labels
xlabel('Beat Number')
ylabel('Mean APD (ms)')

% Plot the variance for the stochastic and determinisitic cases
% max of the variance data for axis
max_data = max([max(max(deterministic_variance(2:end,:))), max(max(stochastic_variance(2:end,:)))]);
% Plot variance data
subplot(1,2,2);
hold on
for i=1:length(conductivities)
    det_colour = det_colours{i};
    plot(squeeze(deterministic_variance(2:end,i)), det_colour, 'LineWidth', 2.0);
    stoch_colour = stoch_colours{i};
    plot(squeeze(stochastic_variance(2:end,i)), stoch_colour, 'LineWidth', 2.0);
end
% axis
ylim([0 1.05*max_data]);
xlim([0 50])
% labels
xlabel('Beat Number')
ylabel('Variance in APD{_{90}} (ms{^2})')

% cosmetics
allAxesInFigure = findall(figureHandle,'type','axes');
for ax=1:length(allAxesInFigure)
    set(allAxesInFigure(ax), 'FontSize', 20)
    set(findall(allAxesInFigure(ax), 'Type','text'), 'FontSize', 26)
    set(allAxesInFigure(ax), 'LineWidth', 2)
    set(allAxesInFigure(ax), 'Box', 'Off')
end

% save figure
if exportFig
	export_fig('Fig6_MeanAndVarAPD.eps', '-eps', '-transparent');
end

% Plot the maximum absolutedifference for the stochastic and determinisitic cases
colours = {'r', 'g', 'b', 'k'};
% Get the range of the data
max_data = max(max(abs_diff));
% open figure
figureHandle = figure('units','normalized','outerposition',[0 0.4 1 0.65]);
hold on
for i=1:length(conductivities)
    colour = colours{i};
    plot(squeeze(abs_diff(2:end,i)), colour, 'LineWidth', 2.0);
end
% limits
ylim([0 1.05*max_data]);
xlim([0 50])
% labels
xlabel('Beat Number')
ylabel('Difference (ms)')

% cosmetics for figure
allAxesInFigure = findall(figureHandle,'type','axes');
for ax=1:length(allAxesInFigure)
    set(allAxesInFigure(ax), 'FontSize', 20)
    set(findall(allAxesInFigure(ax), 'Type','text'), 'FontSize', 26)
    set(allAxesInFigure(ax), 'LineWidth', 2)
    set(allAxesInFigure(ax), 'Box', 'Off')
end

% save figure
if exportFig
	export_fig('Fig6_RandomCellDifference.eps', '-eps', '-transparent');
end

end
