function Figure7
%% Generates the APD plots beat by beat for figure 7. Variables project_path 
% and output_path should be changed to be made appropriate to the user.

% I used export_fig to export my figures. Setting export_fig = 0 will disable
% saving of the figures with export_fig. You can download export_fig from the 
% MathWorks file exchange.


%% Setup
user= 'USER';
project_path = ['/home/' user '/chaste-source/StochasticPhenomenologicalModels'];
output_path = [ '/tmp/' user '/testoutput' ];

matlab_path = [ project_path '/Matlab' ];
% export_fig?
exportFig = 0;
%Conductivities to plot
conductivities = [ 1 0.5 0.1 0.05 ];
% beats to plot
beats= 49;

%% Plot figure for cell distribution
cd(output_path);
cd(['RandomCellModel_CS_' num2str(conductivities(1)) '_archives']) % doesn't matter which
% Import data
allData = importdata('CellModelNumbers.dat'); % generated once per folder
cellDistribution = reshape(allData,101,101);
cellDistribution = cellDistribution';

% Now assign the correct APDs to the cell. 0 is apex 1, 1 is apex 2, 2 is
% base 1 and 3 is base 4.
% Put in the model APDs
apex1Apd = 223.5;
apex2Apd = 127.3;
base1Apd = 268.7;
base2Apd = 182.3;
% assign model APDs to points on mesh
cellApdDistribution = apex1Apd*(cellDistribution==0) + apex2Apd*(cellDistribution==1) + ...
    base1Apd*(cellDistribution==2) + base2Apd*(cellDistribution==3);

% Create figure
cellDistFig = figure('units','normalized','outerposition',[0 0 1 1]);
% plot middle section
imagesc(cellApdDistribution(2:100, 26:74));
% set colour map
colormap hot;
% set colour bar
h=colorbar;
set(gca,'xtick',[]);
set(gca,'xticklabel',[]);
set(gca,'ytick',[]);
set(gca,'yticklabel',[]);
set(h,'FontSize', 20)
y=ylabel(h, 'APD_{90} (ms)');
set(y, 'FontSize', 26);
% save figure
if exportFig
	export_fig('Stoch_RandomCellDistribution.eps', '-eps', '-transparent');
end
cd ..

%% Load APD map data 
% initialise holding arrays
detResultsArray = zeros(99,49, length(conductivities), length(beats));
stochResultsArray = zeros(99,49, length(conductivities), length(beats));
cd(output_path)
% loop over conductivities
for cond =1:length(conductivities)
    % loop over beats
    for i=1:length(beats)
        % Deterministic APD maps
        cd(['RandomCellModel_CS_' num2str(conductivities(cond)) '_archives/archive_stim_' num2str(beats(i)) '/' ]);   
        % Get the data out of the relevant archive folder and reshape to square
        data = importdata('Apd_90_0pt40_Map.dat');
        deterministicdata = reshape(data,101,101);
        deterministicdata = deterministicdata';      
        deterministicdata = deterministicdata(:,25:75);
		cd ../..
			
		% Stochastic APD maps        
        cd(['RandomCellModel_CS_' num2str(conductivities(cond)) '_stochastic_archives/archive_stim_' num2str(beats(i)) '/' ]);       
        % Get the data out of the relevant archive folder and reshape to square
        data = importdata('Apd_90_0pt40_Map.dat');
        stochasticdata = reshape(data,101,101);
        stochasticdata = stochasticdata';
        stochasticdata = stochasticdata(:,25:75);
        cd ../..

        % load data into arrays
        detResultsArray(:,:,cond,i) = deterministicdata(2:end-1, 2:end-1);
        stochResultsArray(:,:,cond,i) = stochasticdata(2:end-1, 2:end-1);
    end
        
end

%% Plot figure 
cd(matlab_path);

% get the data range for the results
minDetResults = min(min(min(min(detResultsArray))));
minStochResults = min(min(min(min(stochResultsArray))));
maxDetResults = max(max(max(max(detResultsArray))));
maxStochResults = max(max(max(max(stochResultsArray))));
dataMin = min(minDetResults, minStochResults);
dataMax = max(maxDetResults, maxStochResults);

% loop over the conductivities
for cond =1:length(conductivities)
    % loop over the beats
    for i=1:length(beats)
        % plot the determinisitic results
        fig=figure('units','normalized','outerposition',[0 0 1 1]);
		% plot data
        imagesc(squeeze(detResultsArray(:,:,cond,i)))
		% remove ticks
        set(gca, 'XTickLabel', '');
        set(gca, 'YTickLabel', '');
        set(gca, 'XTick', []);
        set(gca, 'YTick', []);
		% set colour range
        caxis([dataMin dataMax]);
		% set colour map
        colormap hot;
		% save figure
		if exportFig
        	export_fig(['Fig7_RandomCell_CS_' num2str(conductivities(cond)) '_beat_' num2str(beats(i)) '_det.eps'], '-eps', '-transparent')
        end
		
		% plot the stochastic results
        fig=figure('units','normalized','outerposition',[0 0 1 1]);
		% plot data
        imagesc(squeeze(stochResultsArray(:,:,cond,i)))
		% remove ticks
        set(gca, 'XTickLabel', '');
        set(gca, 'YTickLabel', '');
        set(gca, 'XTick', []);
        set(gca, 'YTick', []);
		% set colour range
        caxis([dataMin dataMax]);
		% set colour map
        colormap hot;
		% save figure
		if exportFig
        	export_fig(['Fig7_RandomCell_CS_' num2str(conductivities(cond)) '_beat_' num2str(beats(i)) '_stoch.eps'], '-eps', '-transparent')
        end
    end % beats  
end % conductivity

% plot colour bar
% make a figure
fig=figure('units','normalized','outerposition',[0 0 1 1]);
% plot a figure
imagesc(squeeze(detResultsArray(:,:,cond,i))); % doesn't matter what the fig is
set(gca, 'XTickLabel', '');
set(gca, 'YTickLabel', '');
% set data limits
caxis([dataMin dataMax]);
% set colour map
colormap hot;
h=colorbar;
set(h,'FontSize', 20)
y=ylabel(h, 'APD_{90} (ms)');
set(y, 'FontSize', 26);
set(y, 'Position', get(y,'Position')+[2 0 0]);
if exportFig 
	export_fig('Fig7_RandomCell_colourbar.eps', '-eps', '-transparent')
end

end
