function Figure8
% Plot the current and variables in Fig 8.

% I used export_fig to export my figures. Setting export_fig = 0 will disable
% saving of the figures with export_fig. You can download export_fig from the 
% MathWorks file exchange.

%% Setup
user= 'USER';
project_path = ['/home/' user '/chaste-source/StochasticPhenomenologicalModels'];
output_path = [ '/tmp/' user '/testoutput' ];
matlab_path = [ project_path '/Matlab' ];
% export_fig?
exportFig = 0;

cd([output_path '/SingleCellSims/BuenoOrovio2008'])

bo08_file_name_base = 'DataTracesbo08_';

% open figure
figureHandle = figure;

% file name
bo08_file_name = [bo08_file_name_base, num2str(1000), 'ms.dat'];
bo08_data = load(bo08_file_name);

% heaviside
H = @(y) heaviside(y);

% get variables
time = bo08_data(:,1);
u = bo08_data(:,2);
v = bo08_data(:,3);
w = bo08_data(:,4);
s = bo08_data(:,5);

% need some parameters to calculate the currents
theta_v = 0.3;
u_u = 1.56;
tau_fi = 0.13;
u_o = 0;
theta_w = 0.13;
tau_o1 = 470;
tau_o2 = 6;
tau_so1 = 40;
tau_so2 = 1.2;
tau_si = 2.901;
k_so = 2;
u_so = 0.65;
theta_o = 0.006;

% calculate time constants
tau_so = tau_so1 +(tau_so2 - tau_so1)*(1+tanh(k_so*(u-u_so)))/2;
tau_o = (1-H(u-theta_o))*tau_o1 + H(u-theta_o)*tau_o2;

% calculate currents
J_fi = -v.*H(u-theta_v).*(u-theta_v).*(u_u-u)/tau_fi;
J_so = (u-u_o).*(1-H(u-theta_w))./tau_o + H(u-theta_w)./tau_so;
J_si = -H(u-theta_w).*w.*s./tau_si;
total_current = -(J_fi+J_so+J_si);

% Plot variables
subplot(1,3,1);
plot(time, u,'k',time, v,'r',time, w,'b',time, s,'g', 'LineWidth', 2.0)
xlabel('Time (ms)')

% Plot currents
subplot(1,3,2);
plot(time, J_fi, 'r', time, J_si, 'b', time, J_so, 'g', time, total_current, 'k','LineWidth', 2.0)
xlim([0 400]);
xlabel('Time (ms)')

%Plot currents during upstroke
subplot(1,3,3);
plot(time, J_fi, 'r', time, J_si, 'b', time, J_so, 'g', time, total_current, 'k','LineWidth', 2.0)
xlim([9 14]);
xlabel('Time (ms)')

% Make cosmetic changes to figures
allAxesInFigure = findall(figureHandle,'type','axes');

for ax=1:length(allAxesInFigure)
    set(findall(allAxesInFigure(ax), 'Type','text'), 'FontSize', 26)
    set(allAxesInFigure(ax), 'FontSize', 20)
    set(allAxesInFigure(ax), 'LineWidth', 2)
    set(allAxesInFigure(ax), 'Box', 'Off')
end

cd( matlab_path );

% save figure
if exportFig
	export_fig('Fig8_BuenoOrovioParameters.eps');
end

end

function y = heaviside(x)
% Heaviside function for calculations
[m,n] = size(x);
y = zeros(m,n);
for i = 1:m
	for j = 1:n
		if x(i,j)==0
			y(i,j) = 0.5;
		elseif x(i,j) < 0
			y(i,j) = 0;
		else
			y(i,j) = 1;
		end	
	end
end

end
