function Figure9
% Plot the convergence plots in Fig. 9. 

% NOTE: You will need to change the code slightly to put the PDE time step and 
% spatial discretisation into the output directory name to generate files that 
% work with this file.
% (TestStochasticsRegularPacing.hpp, line 297).

% I used export_fig to export my figures. Setting export_fig = 0 will disable
% saving of the figures with export_fig. You can download export_fig from the 
% MathWorks file exchange.

%% Setup
user= 'USER';
project_path = ['/home/' user '/chaste-source/StochasticPhenomenologicalModels'];
output_path = [ '/tmp/' user '/testoutput' ];
matlab_path = [ project_path '/Matlab' ];
% export_fig?
exportFig = 0;

%%  Load data
cd(output_path)

pde_time_steps = [ 0.1 0.05 0.025 0.01 0.005 0.0025];
spatial_discretisation = [0.1 0.05 0.01 0.005 0.0025];
conductivity_scales = [1 0.5 0.1 0.05];
wave_velocity_matrix = zeros(length(pde_time_steps), length(spatial_discretisation), length(conductivity_scales));

for cs = 1:length(conductivity_scales)
    for pde = 1:length(pde_time_steps)
        for sd = 1:length(spatial_discretisation)
			cd(['StochasticsRegular_CL_1000_cs_' num2str(conductivity_scales(cs)) '_cell_model_0_pdeTS_' num2str(pde_time_steps(pde)) '_sd_' num2str(spatial_discretisation(sd)) ]);
            % cd into results directory
            cd('output');
            % Construct data into correct spatial distribution.
            x_number = length(0:spatial_discretisation(sd):1)-1;
            y_number = length(0:spatial_discretisation(sd):1)-1;
            % load data files - may need to change name of mesh file
            mesh_pts_raw = dlmread('results_mesh.pts','',[1 0 x_number*y_number 1]);
            data = importdata('UpstrokeTimeMap_0pt40.dat');
            activation_time_matrix = reshape(data,100,100);
            activation_time_matrix = activation_time_matrix';   
            x_vector = mesh_pts_raw(1:x_number,1);
            y_vector = mesh_pts_raw(1:x_number:x_number*y_number,2);
            midpoint_number = length(0:spatial_discretisation(sd):0.5);
            
            % we want to perform these calculations away from the boundary
            % to avoid any adverse effects there
            start_point  = floor(0.25*x_number);
            end_point = ceil(0.75*x_number);
            
            % Calculate time of activation at start
            start_activation_time = activation_time_matrix(midpoint_number, start_point);
            
            % Calculate time of activation at end
            end_activation_time = activation_time_matrix(midpoint_number, end_point);
            
            % Speed = distance / time! Factor of 1000 converts to cm/s
            
            distance = x_vector(end_point) - x_vector(start_point);
            
            wave_velocity = 1000*distance/(end_activation_time-start_activation_time);
            
            wave_velocity_matrix(pde, sd, cs) = wave_velocity;
            % cd back into original folder
            cd(output_path)       
        end % spatial discretisation
    end % pde time steps
end % conductivity scale

%% Plot figures
cd( matlab_path )
colours = {'r', 'g', 'b', 'k','c', 'y'};
figureHandle = figure;
for cs=1:length(conductivity_scales)
    subplot(2,2,cs);
    hold on
    for pde =1:length(pde_time_steps)
        colour_number = mod(pde, length(colours));
        if colour_number == 0
            colour_number = length(colours);
        end
        velocities = reshape(wave_velocity_matrix(pde, :, cs), length(spatial_discretisation),1);
        
        I = find(velocities > 0);     
        
        plot(spatial_discretisation(I), velocities(I), colours{colour_number}, 'LineWidth', 2.0);
    end
 	% label figures
    if (cs == 3 || cs == 4)
        xlabel('Spatial discretisation (cm)')
    end
    if (cs == 1 || cs == 3)
        ylabel('Conduction velocity (cm/s)')
    end
    hold off
	% set limits
    xlim([0 0.1]);
    ylim([0 80]);
    if cs == 4
        xlim([0 0.015]);
        ylim([12 18]);
    end
    
end
       
% cosmetics for the figure
allAxesInFigure = findall(figureHandle,'type','axes');

for ax=1:length(allAxesInFigure)
    set(findall(allAxesInFigure(ax), 'Type','text'), 'FontSize', 26)
    set(allAxesInFigure(ax), 'FontSize', 20)
    set(allAxesInFigure(ax), 'LineWidth', 2)
    set(allAxesInFigure(ax), 'Box', 'Off')
end

if exportFig
	export_fig( 'Fig9_CVconvergence.eps', '-eps', '-transparent' );
end
        
end                   
