#ifndef CELLWALMSLEY2015STOCHASTIC_HPP_
#define CELLWALMSLEY2015STOCHASTIC_HPP_

#include "ChasteSerialization.hpp"
#include <boost/serialization/base_object.hpp>
#include "Walmsley2015.hpp"

class CellWalmsley2015Stochastic : public CellWalmsley2015FromCellML
{
    friend class boost::serialization::access;
    template<class Archive>
    void serialize(Archive & archive, const unsigned int version)
    {
        archive & boost::serialization::base_object<CellWalmsley2015FromCellML >(*this);
    }

    void ConstrainChange(const double& rGatingVariable, double& rChange);

public:
    CellWalmsley2015Stochastic(boost::shared_ptr<AbstractIvpOdeSolver> pSolver, boost::shared_ptr<AbstractStimulusFunction> pIntracellularStimulus, const double xLocation=0.0);
    ~CellWalmsley2015Stochastic();
    void EvaluateYDerivatives(double var_environment__time, const std::vector<double>& rY, std::vector<double>& rDY);
};


// Needs to be included last
#include "SerializationExportWrapper.hpp"
CHASTE_CLASS_EXPORT(CellWalmsley2015Stochastic)

namespace boost
{
    namespace serialization
    {
        template<class Archive>
        inline void save_construct_data(
            Archive & ar, const CellWalmsley2015Stochastic * t, const unsigned int fileVersion)
        {
            const boost::shared_ptr<AbstractIvpOdeSolver> p_solver = t->GetSolver();
            const boost::shared_ptr<AbstractStimulusFunction> p_stimulus = t->GetStimulusFunction();
            ar << p_solver;
            ar << p_stimulus;
        }

        template<class Archive>
        inline void load_construct_data(
            Archive & ar, CellWalmsley2015Stochastic * t, const unsigned int fileVersion)
        {
            boost::shared_ptr<AbstractIvpOdeSolver> p_solver;
            boost::shared_ptr<AbstractStimulusFunction> p_stimulus;
            ar >> p_solver;
            ar >> p_stimulus;
            ::new(t)CellWalmsley2015Stochastic(p_solver, p_stimulus);
        }

    }

}

#endif // CELLWALMSLEY2015STOCHASTIC_HPP_
