/*

Copyright (c) 2005-2015, University of Oxford.
All rights reserved.

University of Oxford means the Chancellor, Masters and Scholars of the
University of Oxford, having an administrative office at Wellington
Square, Oxford OX1 2JD, UK.

This file is part of Chaste.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:
 * Redistributions of source code must retain the above copyright notice,
   this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright notice,
   this list of conditions and the following disclaimer in the documentation
   and/or other materials provided with the distribution.
 * Neither the name of the University of Oxford nor the names of its
   contributors may be used to endorse or promote products derived from this
   software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

*/

#ifndef CELLWALMSLEY2015STOCHASTICCONVERGENCETEST_HPP_
#define CELLWALMSLEY2015STOCHASTICCONVERGENCETEST_HPP_

#include "ChasteSerialization.hpp"
#include <boost/serialization/base_object.hpp>
#include "Walmsley2015.hpp"

class CellWalmsley2015StochasticConvergenceTest : public CellWalmsley2015FromCellML
{
    friend class boost::serialization::access;
    template<class Archive>
    void serialize(Archive & archive, const unsigned int version)
    {
        archive & boost::serialization::base_object<CellWalmsley2015FromCellML >(*this);
    }
    // Function to restrain variables v,w,s between 0 and 1.
    void ConstrainChange(const double& rGatingVariable, double& rChange);

private:
    // Instantiate counter for the number of time steps elapsed in order to correctly reference the lookup vector for the Brownian path.
    unsigned mTimeStepCounter;
    // instantiate vector to contain the Brownian path.
    std::vector<double> mBrownianPathw;
    std::vector<double> mBrownianPaths;
    // rescaling factor to correct the timestep.
    double mCorrectionFactor;
    // Function to load Brownian path data into the vector Brownian_Path. Takes in doubles xLocation, yLocation, an integer 'refinement_level', and a bool 'full_test'
    // refinement_level is an integer between 1 and 5, with 1 denoting the coarsest and 5 the finest Brownian path.
    int GetSumCoefficient(const int refinement_level);
    std::pair< std::vector<double>, std::vector<double> > GetBrownianPath(const double& xLocation, const double& yLocation, const int& refinement_level, const bool& full_test);

public:
    CellWalmsley2015StochasticConvergenceTest(boost::shared_ptr<AbstractIvpOdeSolver> pSolver, boost::shared_ptr<AbstractStimulusFunction> pIntracellularStimulus, const int& refinement_level=1, const bool& full_test=false, const double& xLocation=0.0, const double& yLocation=0.0);
    ~CellWalmsley2015StochasticConvergenceTest();
    void EvaluateYDerivatives(double var_environment__time, const std::vector<double>& rY, std::vector<double>& rDY);
};

// Needs to be included last
#include "SerializationExportWrapper.hpp"
CHASTE_CLASS_EXPORT(CellWalmsley2015StochasticConvergenceTest)

namespace boost
{
    namespace serialization
    {
        template<class Archive>
        inline void save_construct_data(
            Archive & ar, const CellWalmsley2015StochasticConvergenceTest * t, const unsigned int fileVersion)
        {
            const boost::shared_ptr<AbstractIvpOdeSolver> p_solver = t->GetSolver();
            const boost::shared_ptr<AbstractStimulusFunction> p_stimulus = t->GetStimulusFunction();
            ar << p_solver;
            ar << p_stimulus;
        }

        template<class Archive>
        inline void load_construct_data(
            Archive & ar, CellWalmsley2015StochasticConvergenceTest * t, const unsigned int fileVersion)
        {
            boost::shared_ptr<AbstractIvpOdeSolver> p_solver;
            boost::shared_ptr<AbstractStimulusFunction> p_stimulus;
            ar >> p_solver;
            ar >> p_stimulus;
            ::new(t)CellWalmsley2015StochasticConvergenceTest(p_solver, p_stimulus);
        }

    }

}

#endif // CELLWALMSLEY2015STOCHASTICCONVERGENCETEST_HPP_
