#ifndef CELLWALMSLEY2015_PARAMETERVECTOR_STOCHASTIC_HPP_
#define CELLWALMSLEY2015_PARAMETERVECTOR_STOCHASTIC_HPP_

#include "ChasteSerialization.hpp"
#include <boost/serialization/base_object.hpp>
#include "AbstractCardiacCell.hpp"
#include "AbstractStimulusFunction.hpp"
#include "Walmsley2015Stochastic.hpp"

class CellWalmsley2015_ParameterVector_Stochastic : public CellWalmsley2015Stochastic
{
private:
    friend class boost::serialization::access;
    template<class Archive>
    void serialize(Archive & archive, const unsigned int version)
    {
        archive & boost::serialization::base_object<CellWalmsley2015FromCellML>(*this);
    }

public:
    CellWalmsley2015_ParameterVector_Stochastic(boost::shared_ptr<AbstractIvpOdeSolver> pSolver, boost::shared_ptr<AbstractStimulusFunction> pIntracellularStimulus, std::vector<double>& rParameterVector);
};


// Needs to be included last
#include "SerializationExportWrapper.hpp"
CHASTE_CLASS_EXPORT(CellWalmsley2015_ParameterVector_Stochastic)

namespace boost
{
    namespace serialization
    {
        template<class Archive>
        inline void save_construct_data(
            Archive & ar, const CellWalmsley2015_ParameterVector_Stochastic * t, const unsigned int fileVersion)
        {
            const boost::shared_ptr<AbstractIvpOdeSolver> p_solver = t->GetSolver();
            const boost::shared_ptr<AbstractStimulusFunction> p_stimulus = t->GetStimulusFunction();
            ar << p_solver;
            ar << p_stimulus;
        }

        template<class Archive>
        inline void load_construct_data(
            Archive & ar, CellWalmsley2015_ParameterVector_Stochastic * t, const unsigned int fileVersion)
        {
            boost::shared_ptr<AbstractIvpOdeSolver> p_solver;
            boost::shared_ptr<AbstractStimulusFunction> p_stimulus;
            ar >> p_solver;
            ar >> p_stimulus;
            std::vector<double> empty;
            ::new(t)CellWalmsley2015_ParameterVector_Stochastic(p_solver, p_stimulus, empty);
        }

    }

}

#endif // CELLWALMSLEY2015_PARAMETERVECTOR_STOCHASTIC_HPP_
